@@ -2,10 +2,7 @@ use strict;
 use warnings;
 
 package Net::FreshBooks::API::Recurring;
-{
-  $Net::FreshBooks::API::Recurring::VERSION = '0.23';
-}
-
+$Net::FreshBooks::API::Recurring::VERSION = '0.24';
 use Moose;
 extends 'Net::FreshBooks::API::Base';
 with 'Net::FreshBooks::API::Role::CRUD';
@@ -32,8 +29,13 @@ sub _fields {
 
     return {
 
-        amount        => { is => 'ro' },
-        client_id     => { is => 'rw' },
+        amount    => { is => 'ro' },
+        client_id => { is => 'rw' },
+        contacts  => {
+            is           => 'rw',
+            made_of      => 'Net::FreshBooks::API::Client::Contact',
+            presented_as => 'array',
+        },
         currency_code => { is => 'rw' },
         date          => { is => 'rw' },
         discount      => { is => 'rw' },
@@ -82,17 +84,19 @@ __PACKAGE__->meta->make_immutable();
 
 # ABSTRACT: FreshBooks Recurring Item access
 
-
 __END__
+
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Net::FreshBooks::API::Recurring - FreshBooks Recurring Item access
 
 =head1 VERSION
 
-version 0.23
+version 0.24
 
 =head1 SYNOPSIS
 
@@ -250,4 +254,3 @@ This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
 =cut
-
